netapp_ontap.models.cluster_nodes_nvram API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_nvram`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesNvramSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesNvram object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `battery_state: str GET`

    Specifies status of the NVRAM battery. Possible values:

    - battery_ok
    - battery_partially_discharged
    - battery_fully_discharged
    - battery_not_present
    - battery_near_end_of_life
    - battery_at_end_of_life
    - battery_unknown
    - battery_over_charged
    - battery_fully_charged

    Valid choices:

    - battery_ok
    - battery_partially_discharged
    - battery_fully_discharged
    - battery_not_present
    - battery_near_end_of_life
    - battery_at_end_of_life
    - battery_unknown
    - battery_over_charged
    - battery_fully_charged
  `id: Size GET`

    Vendor specific NVRAM ID of the node.